<?php
/**
 * Plugin Name: favicon picker
 * Plugin URI: http://clorith.net
 * Description: Add a favicon to your site, by inserting a rewrite for modern browsers, as well as header tags!
 * Version: 1.0.1
 * Author: Clorith
 *
 */

    class mrstk_favico {

        function __construct()
        {
            add_action( 'admin_init', array( $this, 'admin_init' ) );
            add_action( 'wp_head', array( $this, 'wp_head' ) );
            add_action( 'admin_menu', array( $this, 'populate_menu' ) );
        }

        /*
         * Update our rewrite rule if the favicon setting is changed
         *
         * @param $url The address being added as the favicon
         */
        function rewrite_update( $url ) {
            add_rewrite_rule(
                'favicon.ico$',
                str_replace( get_bloginfo( 'wpurl' ), '', $url ),
                'top'
            );

            flush_rewrite_rules();
        }

        /*
         * Add the proposed favicon relation link to the header, this is not guaranteed to always show the favicon, and browsers will still hit WPURL.TLD/favicon.ico by default, hence our rewrites
         */
        function wp_head() {
            $options = get_option( 'mrstk_favico_options' );

            echo '
                <link rel="shortcut icon" href="' . $options['address'] . '" />
            ';
        }

        /*
         * Callback for our menu function, used to display the options page
         *
         * Kudos to Ram Ratan Maurya at codestag, where I picked up the javascript bit for implementing the WordPress media uploader!
         */
        function populate_menu()
        {
            $page_title  = 'favicon picker';
            $menu_title  = 'favicon.ico';
            $capability  = 'edit_theme_options';
            $parent_slug = 'options-general.php';
            $menu_slug   = 'mrstk-favico';
            $function    = array( $this, 'options_page' );

            add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function );
        }
        function options_page()
        {
            include_once( dirname( __FILE__ ) . '/options.php' );
        }

        /*
         * Initiate our plugin when the admin page is loaded
         */
        function admin_init() {
            if ( isset( $_GET['page'] ) && $_GET['page'] == 'mrstk-favico' )
            {
                wp_enqueue_media();
            }
        }

    }

    // Create our class for referencing functions
    $mrstk_favico = new mrstk_favico();